@@ -27,7 +27,6 @@
 #include <freerdp/api.h>
 #include <freerdp/types.h>
 #include <freerdp/freerdp.h>
-#include <freerdp/utils/event.h>
 #include <freerdp/gdi/gdi.h>
 #if HAVE_FREERDP_1_1
 #include <freerdp/locale/keyboard.h>
@@ -121,6 +120,13 @@ rdp_tab_get_tooltip (VinagreTab *tab)
 				  _("Port:"), vinagre_connection_get_port (conn));
 }
 
+static void
+free_frdpEvent (gpointer event,
+                G_GNUC_UNUSED gpointer user_data)
+{
+    g_free (event);
+}
+
 static void
 vinagre_rdp_tab_dispose (GObject *object)
 {
@@ -138,10 +144,8 @@ vinagre_rdp_tab_dispose (GObject *object)
 
   if (priv->events)
     {
-      while (!g_queue_is_empty (priv->events))
-        g_free ((frdpEvent *) g_queue_pop_head (priv->events));
-
-      g_queue_free (priv->events);
+      g_queue_foreach (priv->events, free_frdpEvent, NULL);
+      g_clear_pointer (&priv->events, g_queue_free);
     }
 
   if (priv->update_id > 0)
@@ -363,7 +367,15 @@ frdp_post_connect (freerdp *instance)
   rdpGdi               *gdi;
   int                   stride;
 
-  gdi_init (instance, CLRBUF_24BPP, NULL);
+  gdi_init (instance,
+#if defined(FREERDP_VERSION_MAJOR) && defined(FREERDP_VERSION_MINOR) && \
+    !(FREERDP_VERSION_MAJOR > 1 || (FREERDP_VERSION_MAJOR == 1 && \
+    FREERDP_VERSION_MINOR >= 2))
+                    CLRBUF_24BPP,
+#else
+                    CLRBUF_32BPP,
+#endif
+                    NULL);
   gdi = instance->context->gdi;
 
   instance->update->BeginPaint = frdp_begin_paint;
